Crate vita49_macros

Crate vita49_macros 

Macros

ack_field
cif_basic
Generates getter/setter implementations for a given CIF field that is represented internally as a simple type. The same type is used for the internal representation and the user-facing value.
cif_field
Generates a getter, setter, and unsetter function for the given CIF field.
cif_radix
Generates getter/setter implementations for a given CIF field that is represented internally as a fixed point number. A “friendly” primitive type is exposed.
cif_radix_masked
Generates getter/setter implementations for a given CIF field that is represented internally as an integer, but some portion of the field is reserve/irrelevant. For example, the field may be a 32-bit int, but only the lower 16 bits are used to represent a fixed point number.
todo_cif_field
Generates a TODO implementation for the given CIF field. If the field is encountered at runtime, the program will panic.

Attribute Macros

cif_fields
Attribute macro that generates struct members with the proper deku conditionals attached. Also automatically handles the CIF7 attributes members associated with each CIF field (e.g. bandwidth_attributes) and generates a size_words() method based on each field’s type.