Generates getter/setter implementations for a given CIF
field that is represented internally as a simple type.
The same type is used for the internal representation and
the user-facing value.
Generates getter/setter implementations for a given CIF
field that is represented internally as a fixed point
number. A “friendly” primitive type is exposed.
Generates getter/setter implementations for a given CIF
field that is represented internally as an integer, but
some portion of the field is reserve/irrelevant. For example,
the field may be a 32-bit int, but only the lower 16 bits are
used to represent a fixed point number.
Attribute macro that generates struct members with the proper
deku conditionals attached. Also automatically handles the
CIF7 attributes members associated with each CIF field (e.g.
bandwidth_attributes) and generates a size_words() method
based on each field’s type.